@@ -117,7 +117,7 @@ camel_html_parser_class_init (CamelHTMLParserClass *klass)
  *
  * Create a new CamelHTMLParser object.
  *
- * Return value: A new CamelHTMLParser widget.
+ * Returns: A new CamelHTMLParser widget.
  **/
 CamelHTMLParser *
 camel_html_parser_new (void)
@@ -126,7 +126,6 @@ camel_html_parser_new (void)
 	return new;
 }
 
-
 void camel_html_parser_set_data(CamelHTMLParser *hp, const gchar *start, gint len, gint last)
 {
 	CamelHTMLParserPrivate *p = hp->priv;
@@ -376,7 +375,6 @@ static struct {
 	{ 8659,	"dArr",	/* downwards double arrow, U+21D3 ISOamsa */ },
 	{ 8660,	"hArr",	/* left right double arrow, U+21D4 ISOamsa */ },
 
-
 	{ 8704,	"forall",/* for all, U+2200 ISOtech */ },
 	{ 8706,	"part",	/* partial differential, U+2202 ISOtech */ },
 	{ 8707,	"exist",/* there exists, U+2203 ISOtech */ },
@@ -468,7 +466,7 @@ static void tokenise_setup(void)
 
 	if (entities == NULL) {
 		entities = g_hash_table_new(g_str_hash, g_str_equal);
-		for (i=0;i<sizeof(entity_map)/sizeof(entity_map[0]);i++) {
+		for (i = 0; i < G_N_ELEMENTS (entity_map); i++) {
 			g_hash_table_insert(entities, (gchar *)entity_map[i].name, GUINT_TO_POINTER(entity_map[i].val));
 		}
 	}
