@@ -454,6 +454,8 @@ camel_mime_part_get_disposition (CamelMimePart *mime_part)
  * Returned pointer is owned by #mime_part.
  *
  * Returns: the disposition structure
+ *
+ * Since: 2.30
  **/
 const CamelContentDisposition *
 camel_mime_part_get_content_disposition (CamelMimePart *mime_part)
@@ -712,7 +714,7 @@ camel_mime_part_set_content_type (CamelMimePart *mime_part, const gchar *content
 CamelContentType *
 camel_mime_part_get_content_type (CamelMimePart *mime_part)
 {
-	return ((CamelDataWrapper *) mime_part)->mime_type;
+	return camel_data_wrapper_get_mime_type_field ((CamelDataWrapper *) mime_part);
 }
 
 static void
@@ -1100,6 +1102,8 @@ camel_mime_part_set_content (CamelMimePart *mime_part,
  * Get the decoded size of the MIME part's content.
  *
  * Returns: the size of the MIME part's content in bytes.
+ *
+ * Since: 2.22
  **/
 gsize
 camel_mime_part_get_content_size (CamelMimePart *mime_part)
