@@ -87,7 +87,8 @@ gint		 camel_imapx_stream_nstring_stream(CamelIMAPXStream *is, CamelStream **str
 gint		 camel_imapx_stream_text		(CamelIMAPXStream *is, guchar **text, CamelException *ex);
 
 /* gets a 'number' */
-guint32		 camel_imapx_stream_number(CamelIMAPXStream *is, CamelException *ex);
+guint64		 camel_imapx_stream_number	(CamelIMAPXStream *is,
+						 CamelException *ex);
 
 /* skips the rest of a line, including literals, etc */
 gint camel_imapx_stream_skip(CamelIMAPXStream *is, CamelException *ex);
