@@ -1,15 +1,15 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* camel-pop3-folder.c : class for a pop3 folder */
 
-/* 
+/*
  * Authors:
  *   Dan Winship <danw@ximian.com>
  *   Michael Zucchi <notzed@ximian.com>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -52,21 +52,21 @@ static void pop3_refresh_info (CamelFolder *folder, CamelException *ex);
 static void pop3_sync (CamelFolder *folder, gboolean expunge, CamelException *ex);
 static gint pop3_get_message_count (CamelFolder *folder);
 static GPtrArray *pop3_get_uids (CamelFolder *folder);
-static CamelMimeMessage *pop3_get_message (CamelFolder *folder, const char *uid, CamelException *ex);
-static gboolean pop3_set_message_flags (CamelFolder *folder, const char *uid, guint32 flags, guint32 set);
-static char* pop3_get_filename (CamelFolder *folder, const char *uid, CamelException *ex);
+static CamelMimeMessage *pop3_get_message (CamelFolder *folder, const gchar *uid, CamelException *ex);
+static gboolean pop3_set_message_flags (CamelFolder *folder, const gchar *uid, guint32 flags, guint32 set);
+static gchar * pop3_get_filename (CamelFolder *folder, const gchar *uid, CamelException *ex);
 
 static void
 camel_pop3_folder_class_init (CamelPOP3FolderClass *camel_pop3_folder_class)
 {
 	CamelFolderClass *camel_folder_class = CAMEL_FOLDER_CLASS(camel_pop3_folder_class);
-	
+
 	parent_class = CAMEL_FOLDER_CLASS(camel_folder_get_type());
-	
+
 	/* virtual method overload */
 	camel_folder_class->refresh_info = pop3_refresh_info;
 	camel_folder_class->sync = pop3_sync;
-	
+
 	camel_folder_class->get_message_count = pop3_get_message_count;
 	camel_folder_class->get_uids = pop3_get_uids;
 	camel_folder_class->free_uids = camel_folder_free_shallow;
@@ -80,7 +80,7 @@ CamelType
 camel_pop3_folder_get_type (void)
 {
 	static CamelType camel_pop3_folder_type = CAMEL_INVALID_TYPE;
-	
+
 	if (!camel_pop3_folder_type) {
 		camel_pop3_folder_type = camel_type_register (CAMEL_FOLDER_TYPE, "CamelPOP3Folder",
 							      sizeof (CamelPOP3Folder),
@@ -90,7 +90,7 @@ camel_pop3_folder_get_type (void)
 							      NULL,
 							      (CamelObjectFinalizeFunc) pop3_finalize);
 	}
-	
+
 	return camel_pop3_folder_type;
 }
 
@@ -100,7 +100,7 @@ pop3_finalize (CamelObject *object)
 	CamelPOP3Folder *pop3_folder = CAMEL_POP3_FOLDER (object);
 	CamelPOP3FolderInfo **fi = (CamelPOP3FolderInfo **)pop3_folder->uids->pdata;
 	CamelPOP3Store *pop3_store = (CamelPOP3Store *)((CamelFolder *)pop3_folder)->parent_store;
-	int i;
+	gint i;
 
 	if (pop3_folder->uids) {
 		for (i=0;i<pop3_folder->uids->len;i++,fi++) {
@@ -109,11 +109,11 @@ pop3_finalize (CamelObject *object)
 					;
 				camel_pop3_engine_command_free(pop3_store->engine, fi[0]->cmd);
 			}
-			
+
 			g_free(fi[0]->uid);
 			g_free(fi[0]);
 		}
-		
+
 		g_ptr_array_free(pop3_folder->uids, TRUE);
 		g_hash_table_destroy(pop3_folder->uids_uid);
 	}
@@ -125,23 +125,23 @@ camel_pop3_folder_new (CamelStore *parent, CamelException *ex)
 	CamelFolder *folder;
 
 	d(printf("opening pop3 INBOX folder\n"));
-	
+
 	folder = CAMEL_FOLDER (camel_object_new (CAMEL_POP3_FOLDER_TYPE));
 	camel_folder_construct (folder, parent, "inbox", "inbox");
-	
+
 	/* mt-ok, since we dont have the folder-lock for new() */
 	camel_folder_refresh_info (folder, ex);/* mt-ok */
 	if (camel_exception_is_set (ex)) {
 		camel_object_unref (CAMEL_OBJECT (folder));
 		folder = NULL;
 	}
-	
+
 	return folder;
 }
 
 /* create a uid from md5 of 'top' output */
 static void
-cmd_builduid(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
+cmd_builduid(CamelPOP3Engine *pe, CamelPOP3Stream *stream, gpointer data)
 {
 	GChecksum *checksum;
 	CamelPOP3FolderInfo *fi = data;
@@ -186,11 +186,11 @@ cmd_builduid(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
 }
 
 static void
-cmd_list(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
+cmd_list(CamelPOP3Engine *pe, CamelPOP3Stream *stream, gpointer data)
 {
-	int ret;
-	unsigned int len, id, size;
-	unsigned char *line;
+	gint ret;
+	guint len, id, size;
+	guchar *line;
 	CamelFolder *folder = data;
 	CamelPOP3Store *pop3_store = CAMEL_POP3_STORE (folder->parent_store);
 	CamelPOP3FolderInfo *fi;
@@ -198,7 +198,7 @@ cmd_list(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
 	do {
 		ret = camel_pop3_stream_line(stream, &line, &len);
 		if (ret>=0) {
-			if (sscanf((char *) line, "%u %u", &id, &size) == 2) {
+			if (sscanf((gchar *) line, "%u %u", &id, &size) == 2) {
 				fi = g_malloc0(sizeof(*fi));
 				fi->size = size;
 				fi->id = id;
@@ -213,22 +213,22 @@ cmd_list(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
 }
 
 static void
-cmd_uidl(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
+cmd_uidl(CamelPOP3Engine *pe, CamelPOP3Stream *stream, gpointer data)
 {
-	int ret;
-	unsigned int len;
-	unsigned char *line;
-	char uid[1025];
-	unsigned int id;
+	gint ret;
+	guint len;
+	guchar *line;
+	gchar uid[1025];
+	guint id;
 	CamelPOP3FolderInfo *fi;
 	CamelPOP3Folder *folder = data;
-	
+
 	do {
 		ret = camel_pop3_stream_line(stream, &line, &len);
 		if (ret>=0) {
-			if (strlen((char *) line) > 1024)
+			if (strlen((gchar *) line) > 1024)
 				line[1024] = 0;
-			if (sscanf((char *) line, "%u %s", &id, uid) == 2) {
+			if (sscanf((gchar *) line, "%u %s", &id, uid) == 2) {
 				fi = g_hash_table_lookup(folder->uids_id, GINT_TO_POINTER(id));
 				if (fi) {
 					camel_operation_progress(NULL, (fi->index+1) * 100 / folder->uids->len);
@@ -242,13 +242,13 @@ cmd_uidl(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
 	} while (ret>0);
 }
 
-static void 
+static void
 pop3_refresh_info (CamelFolder *folder, CamelException *ex)
 {
 	CamelPOP3Store *pop3_store = CAMEL_POP3_STORE (folder->parent_store);
 	CamelPOP3Folder *pop3_folder = (CamelPOP3Folder *) folder;
 	CamelPOP3Command *pcl, *pcu = NULL;
-	int i;
+	gint i;
 
 	camel_operation_start (NULL, _("Retrieving POP summary"));
 
@@ -273,9 +273,9 @@ pop3_refresh_info (CamelFolder *folder, CamelException *ex)
 	}
 
 	/* TODO: check every id has a uid & commands returned OK too? */
-	
+
 	camel_pop3_engine_command_free(pop3_store->engine, pcl);
-	
+
 	if (pop3_store->engine->capa & CAMEL_POP3_CAP_UIDL) {
 		camel_pop3_engine_command_free(pop3_store->engine, pcu);
 	} else {
@@ -292,7 +292,7 @@ pop3_refresh_info (CamelFolder *folder, CamelException *ex)
 
 	/* dont need this anymore */
 	g_hash_table_destroy(pop3_folder->uids_id);
-	
+
 	camel_operation_end (NULL);
 	return;
 }
@@ -302,7 +302,7 @@ pop3_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
 {
 	CamelPOP3Folder *pop3_folder;
 	CamelPOP3Store *pop3_store;
-	int i;
+	gint i;
 	CamelPOP3FolderInfo *fi;
 
 	pop3_folder = CAMEL_POP3_FOLDER (folder);
@@ -363,11 +363,11 @@ pop3_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
 }
 
 static gboolean
-pop3_get_message_time_from_cache (CamelFolder *folder, const char *uid, time_t *message_time)
+pop3_get_message_time_from_cache (CamelFolder *folder, const gchar *uid, time_t *message_time)
 {
 	CamelPOP3Store *pop3_store;
 	CamelStream *stream = NULL;
-	char buffer[1];
+	gchar buffer[1];
 	gboolean res = FALSE;
 
 	g_return_val_if_fail (folder != NULL, FALSE);
@@ -404,17 +404,18 @@ pop3_get_message_time_from_cache (CamelFolder *folder, const char *uid, time_t *
 	return res;
 }
 
-int
-camel_pop3_delete_old(CamelFolder *folder, int days_to_delete,	CamelException *ex)
+gint
+camel_pop3_delete_old(CamelFolder *folder, gint days_to_delete,	CamelException *ex)
 {
 	CamelPOP3Folder *pop3_folder;
 	CamelPOP3FolderInfo *fi;
-	int i;
+	gint i;
 	CamelPOP3Store *pop3_store;
-	time_t temp, message_time;
+	CamelMimeMessage *message;
+	time_t temp, message_time = 0;
 
 	pop3_folder = CAMEL_POP3_FOLDER (folder);
-	pop3_store = CAMEL_POP3_STORE (CAMEL_FOLDER(pop3_folder)->parent_store);	
+	pop3_store = CAMEL_POP3_STORE (CAMEL_FOLDER(pop3_folder)->parent_store);
 	temp = time(&temp);
 
 	d(printf("%s(%d): pop3_folder->uids->len=[%d]\n", __FILE__, __LINE__, pop3_folder->uids->len));
@@ -422,26 +423,34 @@ camel_pop3_delete_old(CamelFolder *folder, int days_to_delete,	CamelException *e
 		fi = pop3_folder->uids->pdata[i];
 
 		d(printf("%s(%d): fi->uid=[%s]\n", __FILE__, __LINE__, fi->uid));
-		if (pop3_get_message_time_from_cache (folder, fi->uid, &message_time)) {
-			double time_diff = difftime(temp,message_time);
-			int day_lag = time_diff/(60*60*24);
+		if (!pop3_get_message_time_from_cache (folder, fi->uid, &message_time)) {
+			d(printf("could not get message time from cache, trying from pop3\n"));
+			message = pop3_get_message (folder, fi->uid, ex);
+			if (message) {
+				message_time = message->date + message->date_offset;
+				camel_object_unref(message);
+			}
+		}
+
+		if (message_time) {
+			gdouble time_diff = difftime(temp,message_time);
+			gint day_lag = time_diff/(60*60*24);
 
 			d(printf("%s(%d): message_time= [%ld]\n", __FILE__, __LINE__, message_time));
-			d(printf("%s(%d): day_lag=[%d] \t days_to_delete=[%d]\n", 
-				 __FILE__, __LINE__, day_lag, days_to_delete));
+			d(printf("%s(%d): day_lag=[%d] \t days_to_delete=[%d]\n",
+				__FILE__, __LINE__, day_lag, days_to_delete));
 
-			if( day_lag > days_to_delete)
-			{
+			if (day_lag > days_to_delete) {
 				if (fi->cmd) {
 					while (camel_pop3_engine_iterate(pop3_store->engine, fi->cmd) > 0) {
 						; /* do nothing - iterating until end */
 					}
-					
+
 					camel_pop3_engine_command_free(pop3_store->engine, fi->cmd);
 					fi->cmd = NULL;
 				}
 				d(printf("%s(%d): Deleting old messages\n", __FILE__, __LINE__));
-				fi->cmd = camel_pop3_engine_command_new(pop3_store->engine, 
+				fi->cmd = camel_pop3_engine_command_new(pop3_store->engine,
 									0,
 									NULL,
 									NULL,
@@ -475,11 +484,11 @@ camel_pop3_delete_old(CamelFolder *folder, int days_to_delete,	CamelException *e
 }
 
 static void
-cmd_tocache(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
+cmd_tocache(CamelPOP3Engine *pe, CamelPOP3Stream *stream, gpointer data)
 {
 	CamelPOP3FolderInfo *fi = data;
-	char buffer[2048];
-	int w = 0, n;
+	gchar buffer[2048];
+	gint w = 0, n;
 
 	/* What if it fails? */
 
@@ -512,13 +521,13 @@ done:
 	} else {
 		fi->err = 0;
 	}
-	
+
 	camel_object_unref((CamelObject *)fi->stream);
 	fi->stream = NULL;
 }
 
-static char*
-pop3_get_filename (CamelFolder *folder, const char *uid, CamelException *ex)
+static gchar *
+pop3_get_filename (CamelFolder *folder, const gchar *uid, CamelException *ex)
 {
 	CamelPOP3Folder *pop3_folder = (CamelPOP3Folder *)folder;
 	CamelPOP3Store *pop3_store = (CamelPOP3Store *)((CamelFolder *)pop3_folder)->parent_store;
@@ -535,15 +544,15 @@ pop3_get_filename (CamelFolder *folder, const char *uid, CamelException *ex)
 }
 
 static CamelMimeMessage *
-pop3_get_message (CamelFolder *folder, const char *uid, CamelException *ex)
+pop3_get_message (CamelFolder *folder, const gchar *uid, CamelException *ex)
 {
 	CamelMimeMessage *message = NULL;
 	CamelPOP3Store *pop3_store = CAMEL_POP3_STORE (folder->parent_store);
 	CamelPOP3Folder *pop3_folder = (CamelPOP3Folder *)folder;
 	CamelPOP3Command *pcr;
 	CamelPOP3FolderInfo *fi;
-	char buffer[1];
-	int i, last;
+	gchar buffer[1];
+	gint i, last;
 	CamelStream *stream = NULL;
 
 	fi = g_hash_table_lookup(pop3_folder->uids_uid, uid);
@@ -583,7 +592,7 @@ pop3_get_message (CamelFolder *folder, const char *uid, CamelException *ex)
 			goto fail;
 		}
 	}
-	
+
 	/* check to see if we have safely written flag set */
 	if (pop3_store->cache == NULL
 	    || (stream = camel_data_cache_get(pop3_store->cache, "cache", fi->uid, NULL)) == NULL
@@ -609,7 +618,7 @@ pop3_get_message (CamelFolder *folder, const char *uid, CamelException *ex)
 			last = MIN(i+10, pop3_folder->uids->len);
 			for (;i<last;i++) {
 				CamelPOP3FolderInfo *pfi = pop3_folder->uids->pdata[i];
-				
+
 				if (pfi->uid && pfi->cmd == NULL) {
 					pfi->stream = camel_data_cache_add(pop3_store->cache, "cache", pfi->uid, NULL);
 					if (pfi->stream) {
@@ -671,7 +680,7 @@ fail:
 }
 
 static gboolean
-pop3_set_message_flags (CamelFolder *folder, const char *uid, guint32 flags, guint32 set)
+pop3_set_message_flags (CamelFolder *folder, const gchar *uid, guint32 flags, guint32 set)
 {
 	CamelPOP3Folder *pop3_folder = CAMEL_POP3_FOLDER (folder);
 	CamelPOP3FolderInfo *fi;
@@ -694,7 +703,7 @@ static gint
 pop3_get_message_count (CamelFolder *folder)
 {
 	CamelPOP3Folder *pop3_folder = CAMEL_POP3_FOLDER (folder);
-	
+
 	return pop3_folder->uids->len;
 }
 
@@ -704,12 +713,12 @@ pop3_get_uids (CamelFolder *folder)
 	CamelPOP3Folder *pop3_folder = CAMEL_POP3_FOLDER (folder);
 	GPtrArray *uids = g_ptr_array_new();
 	CamelPOP3FolderInfo **fi = (CamelPOP3FolderInfo **)pop3_folder->uids->pdata;
-	int i;
+	gint i;
 
 	for (i=0;i<pop3_folder->uids->len;i++,fi++) {
 		if (fi[0]->uid)
 			g_ptr_array_add(uids, fi[0]->uid);
 	}
-	
+
 	return uids;
 }
